@@ -2,6 +2,6 @@ from .image import (
     get_image_extension, is_transparent, exif_orientation,
     correct_colorspace, is_animated_gif, has_animated_gif_support, process_image,
     smart_resize)
-from .paths import get_upload_foldername, get_media_path, get_relative_media_url
+from .paths import get_upload_foldername
 from .sizes import get_min_size
 from . import jsonutils as json
