@@ -42,14 +42,15 @@ from django.views.decorators.csrf import csrf_exempt
 
 import PIL.Image
 
+from generic_plus.utils import get_relative_media_url
+
 from cropduster.files import ImageFile
 from cropduster.models import Thumb, Size, StandaloneImage, Image
 from cropduster.settings import (
     CROPDUSTER_PREVIEW_WIDTH as PREVIEW_WIDTH,
     CROPDUSTER_PREVIEW_HEIGHT as PREVIEW_HEIGHT)
 from cropduster.utils import (
-    json, get_relative_media_url, is_animated_gif, has_animated_gif_support,
-    process_image)
+    json, is_animated_gif, has_animated_gif_support, process_image)
 from cropduster.exceptions import json_error, CropDusterResizeException, full_exc_info
 
 from .base import View
@@ -212,6 +213,8 @@ def upload(request):
     is_standalone = bool(form_data.get('standalone'))
 
     orig_file_path = form_data['image'].name
+    if isinstance(orig_file_path, unicode):
+        orig_file_path = orig_file_path.encode('utf-8')
     orig_image = get_relative_media_url(orig_file_path)
     img = PIL.Image.open(orig_file_path)
     (w, h) = (orig_w, orig_h) = img.size
